--- old/usr/src/lib/libm/common/m9x/scalbln.c	2019-06-06 20:40:36.186401246 +0000
+++ new/usr/src/lib/libm/common/m9x/scalbln.c	2019-06-06 20:40:36.204055036 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -30,9 +31,10 @@
 #pragma weak __scalbln = scalbln
 
 #include "libm.h"
-#include <float.h>		/* DBL_MAX, DBL_MIN */
+#include <float.h>			/* DBL_MAX, DBL_MIN */
 
 static const double twom54 = 5.5511151231257827021181583404541015625e-17;
+
 #if defined(__x86)
 static const double two52 = 4503599627370496.0;
 #else
@@ -40,7 +42,8 @@
  * Normalize non-zero subnormal x and return biased exponent of x in [-51,0]
  */
 static int
-ilogb_biased(unsigned *px) {
+ilogb_biased(unsigned *px)
+{
 	int s = 52;
 	unsigned v = px[HIWORD] & ~0x80000000, w = px[LOWORD], t = v;
 
@@ -48,14 +51,19 @@
 		s -= 32;
 	else
 		t = w;
+
 	if (t & 0xffff0000)
 		s -= 16, t >>= 16;
+
 	if (t & 0xff00)
 		s -= 8, t >>= 8;
+
 	if (t & 0xf0)
 		s -= 4, t >>= 4;
+
 	t <<= 1;
 	s -= (0xffffaa50 >> t) & 0x3;
+
 	if (s < 32) {
 		v = (v << s) | w >> (32 - s);
 		w <<= s;
@@ -63,44 +71,55 @@
 		v = w << (s - 32);
 		w = 0;
 	}
+
 	px[HIWORD] = (px[HIWORD] & 0x80000000) | v;
 	px[LOWORD] = w;
 	return (1 - s);
 }
-#endif	/* defined(__x86) */
+#endif /* defined(__x86) */
 
 double
-scalbln(double x, long n) {
-	int *px = (int *) &x, ix, k;
+scalbln(double x, long n)
+{
+	int *px = (int *)&x, ix, k;
 
 	ix = px[HIWORD] & ~0x80000000;
 	k = ix >> 20;
+
 	if (k == 0x7ff)
 #if defined(FPADD_TRAPS_INCOMPLETE_ON_NAN)
 		return ((px[HIWORD] & 0x80000) != 0 ? x : x + x);
-		/* assumes sparc-like QNaN */
+
+	/* assumes sparc-like QNaN */
 #else
 		return (x + x);
 #endif
+
 	if ((px[LOWORD] | ix) == 0 || n == 0)
 		return (x);
+
 	if (k == 0) {
 #if defined(__x86)
 		x *= two52;
 		k = ((px[HIWORD] & ~0x80000000) >> 20) - 52;
 #else
-		k = ilogb_biased((unsigned *) px);
+		k = ilogb_biased((unsigned *)px);
 #endif
 	}
-	k += (int) n;
+
+	k += (int)n;
+
 	if (n > 5000 || k > 0x7fe)
 		return (DBL_MAX * copysign(DBL_MAX, x));
+
 	if (n < -5000 || k <= -54)
 		return (DBL_MIN * copysign(DBL_MIN, x));
+
 	if (k > 0) {
 		px[HIWORD] = (px[HIWORD] & ~0x7ff00000) | (k << 20);
 		return (x);
 	}
+
 	k += 54;
 	px[HIWORD] = (px[HIWORD] & ~0x7ff00000) | (k << 20);
 	return (x * twom54);
